@@ -6,10 +6,12 @@ from django.contrib.postgres.aggregates import ArrayAgg
 from django.db.models import F
 from django.db.models.expressions import Window
 from django.db.models.functions.window import FirstValue
+from django.http import StreamingHttpResponse
 from django.shortcuts import get_object_or_404
 from django.utils.dateparse import parse_datetime
 from django_filters import filters
 from drf_spectacular.utils import OpenApiParameter, extend_schema
+from jinja2 import Template
 from rest_framework import mixins
 from rest_framework.response import Response
 from rest_framework.reverse import reverse
@@ -434,27 +436,24 @@ class UnpaginatedCollectionVersionViewSet(CollectionVersionViewSet):
         """
         distro_content = self._distro_content
 
-        return CollectionVersion.objects.select_related("content_ptr__contentartifact").filter(
-            pk__in=distro_content
-        )
+        return CollectionVersion.objects.select_related().filter(pk__in=distro_content)
 
     def list(self, request, *args, **kwargs):
         """
         Returns paginated CollectionVersions list.
         """
-        queryset = self.filter_queryset(self.get_queryset())
-        queryset = sorted(
-            queryset, key=lambda obj: semantic_version.Version(obj.version), reverse=True
-        )
+        queryset = self.get_queryset().iterator()
 
         context = self.get_serializer_context()
-        page = self.paginate_queryset(queryset)
-        if page is not None:
-            serializer = self.get_serializer(page, many=True, context=context)
-            return self.get_paginated_response(serializer.data)
-
-        serializer = self.get_serializer(queryset, many=True, context=context)
-        return Response(serializer.data)
+        cvs_template_string = (
+            "[{% for cv in versions %}"
+            "{{ cv|tojson }}{% if not loop.last %},{% endif %}"
+            "{% endfor %}]"
+        )
+        cvs_template = Template(cvs_template_string)
+        serialized_map = (self.get_serializer(x, context=context).data for x in queryset)
+        streamed = (x.encode("utf-8") for x in cvs_template.stream(versions=serialized_map))
+        return StreamingHttpResponse(streamed)
 
 
 class CollectionVersionDocsViewSet(
