@@ -19,6 +19,7 @@ from galaxy_importer.collection import CollectionFilename
 from galaxy_importer.exceptions import ImporterError
 from pkg_resources import Requirement
 from rq.job import get_current_job
+from rest_framework.serializers import ValidationError
 
 from pulpcore.plugin.constants import TASK_STATES
 from pulpcore.plugin.models import (
@@ -104,7 +105,7 @@ def update_collection_remote(remote_pk, *args, **kwargs):
         serializer.save()
 
 
-def sync(remote_pk, repository_pk, mirror, optimize, excludes=None):
+def sync(remote_pk, repository_pk, mirror, optimize):
     """
     Sync Collections with ``remote_pk``, and save a new RepositoryVersion for ``repository_pk``.
 
@@ -113,7 +114,6 @@ def sync(remote_pk, repository_pk, mirror, optimize, excludes=None):
         repository_pk (str): The repository PK.
         mirror (bool): True for mirror mode, False for additive.
         optimize (boolean): Whether to optimize sync or not.
-        excludes (str): Requirements file string of collections to exclude from the sync
 
     Raises:
         ValueError: If the remote does not specify a URL to sync.
@@ -126,10 +126,11 @@ def sync(remote_pk, repository_pk, mirror, optimize, excludes=None):
     if not remote.url:
         raise ValueError(_("A CollectionRemote must have a 'url' specified to synchronize."))
 
-    if excludes is not None:
-        excludes = parse_collections_requirements_file(excludes)
+    first_stage = CollectionSyncFirstStage(remote, repository, optimize)
+    if first_stage.should_sync is False:
+        log.debug(_("no-op: remote wasn't updated since last sync."))
+        return
 
-    first_stage = CollectionSyncFirstStage(remote, repository, optimize, excludes or [])
     d_version = AnsibleDeclarativeVersion(first_stage, repository, mirror=mirror)
     d_version.create()
 
@@ -161,7 +162,7 @@ def sync(remote_pk, repository_pk, mirror, optimize, excludes=None):
 def parse_requirements_entry(requirements_entry):
     """Parses a `RequirementsFileEntry` and returns a `Requirement` object."""
     if requirements_entry.version == "*":
-        requirement_version = Requirement.parse(requirements_entry.name)
+        requirement_version = Requirement.parse("collection")
     else:
         # We need specifiers to enforce Requirement object criteria
         # https://setuptools.readthedocs.io/en/latest/pkg_resources.html#requirements-parsing
@@ -169,9 +170,9 @@ def parse_requirements_entry(requirements_entry):
         # If requirements_entry.version is a valid version, adds == specifier to the requirement
         try:
             Version(requirements_entry.version)
-            req_to_parse = f"{requirements_entry.name}=={requirements_entry.version}"
+            req_to_parse = f"collection=={requirements_entry.version}"
         except ValueError:
-            req_to_parse = f"{requirements_entry.name}{requirements_entry.version}"
+            req_to_parse = f"collection{requirements_entry.version}"
 
         requirement_version = Requirement.parse(req_to_parse)
     return requirement_version
@@ -366,7 +367,7 @@ class CollectionSyncFirstStage(Stage):
     The first stage of a pulp_ansible sync pipeline.
     """
 
-    def __init__(self, remote, repository, optimize, excludes):
+    def __init__(self, remote, repository, optimize):
         """
         The first stage of a pulp_ansible sync pipeline.
 
@@ -374,7 +375,6 @@ class CollectionSyncFirstStage(Stage):
             remote (CollectionRemote): The remote data to be used when syncing
             repository (AnsibleRepository): The repository being syncedself.
             optimize (boolean): Whether to optimize sync or not.
-            excludes (List[RequirementsFileEntry]): Collections to exclude from the sync
 
         """
         super().__init__()
@@ -384,9 +384,9 @@ class CollectionSyncFirstStage(Stage):
         self.repository = repository
         self.optimize = optimize
         self.collection_info = parse_collections_requirements_file(remote.requirements_file)
-        self.exclude_info = {req.name: req for req in map(parse_requirements_entry, excludes)}
         self.deprecations = Q()
 
+        self.exclude_info = {}
         self._unpaginated_collection_metadata = None
         self._unpaginated_collection_version_metadata = None
         self.last_synced_metadata_time = None
@@ -394,6 +394,11 @@ class CollectionSyncFirstStage(Stage):
         # Interpret download policy
         self.deferred_download = self.remote.policy != Remote.IMMEDIATE
 
+        # Check if we should sync
+        self.should_sync = not optimize or asyncio.get_event_loop().run_until_complete(
+            self._should_we_sync()
+        )
+
     @alru_cache(maxsize=128)
     async def _get_root_api(self, root):
         """
@@ -455,8 +460,8 @@ class CollectionSyncFirstStage(Stage):
             version=metadata["version"],
         )
         cv_unique = attrgetter("namespace", "name", "version")(collection_version)
-        fullname = ".".join(cv_unique[:2])
-        if fullname in self.exclude_info and cv_unique[2] in self.exclude_info[fullname]:
+        fullname, version = f"{cv_unique[0]}.{cv_unique[1]}", cv_unique[2]
+        if fullname in self.exclude_info and version in self.exclude_info[fullname]:
             return
 
         info = metadata["metadata"]
@@ -592,15 +597,32 @@ class CollectionSyncFirstStage(Stage):
         root_endpoint, api_version = await self._get_root_api(self.remote.url)
         self._api_version = api_version
         if api_version > 2:
+            loop = asyncio.get_event_loop()
+
             collection_endpoint = f"{root_endpoint}/collections/all/"
-            downloader = self.remote.get_downloader(
+            excludes_endpoint = f"{root_endpoint}/excludes/"
+            col_downloader = self.remote.get_downloader(
                 url=collection_endpoint, silence_errors_for_response_status_codes={404}
             )
-            try:
-                collection_metadata_list = parse_metadata(await downloader.run())
-            except FileNotFoundError:
-                pass
-            else:
+            exc_downloader = self.remote.get_downloader(
+                url=excludes_endpoint, silence_errors_for_response_status_codes={404}
+            )
+            tasks = [loop.create_task(col_downloader.run()), loop.create_task(exc_downloader.run())]
+            col_results, exc_results = await asyncio.gather(*tasks, return_exceptions=True)
+
+            if not isinstance(exc_results, FileNotFoundError):
+                excludes_response = parse_metadata(exc_results)
+                if excludes_response:
+                    try:
+                        excludes_list = parse_collections_requirements_file(excludes_response)
+                    except ValidationError:
+                        pass
+                    else:
+                        excludes = {r.name: parse_requirements_entry(r) for r in excludes_list}
+                        self.exclude_info.update(excludes)
+
+            if not isinstance(col_results, FileNotFoundError):
+                collection_metadata_list = parse_metadata(col_results)
                 self._unpaginated_collection_metadata = defaultdict(dict)
                 for collection in collection_metadata_list:
                     namespace = collection["namespace"]
@@ -739,12 +761,6 @@ class CollectionSyncFirstStage(Stage):
         """
         Build and emit `DeclarativeContent` from the ansible metadata.
         """
-        if self.optimize:
-            should_we_sync = await self._should_we_sync()
-            if should_we_sync is False:
-                log.debug(_("no-op: remote wasn't updated since last sync."))
-                return
-
         tasks = []
         loop = asyncio.get_event_loop()
 
@@ -863,7 +879,10 @@ class CollectionContentSaver(ContentSaver):
                     )
                     if runtime_metadata:
                         runtime_yaml = yaml.safe_load(runtime_metadata)
-                        collection_version.requires_ansible = runtime_yaml.get("requires_ansible")
+                        if runtime_yaml:
+                            collection_version.requires_ansible = runtime_yaml.get(
+                                "requires_ansible"
+                            )
                     manifest_data = json.load(
                         get_file_obj_from_tarball(tar, "MANIFEST.json", artifact.file.name)
                     )
