@@ -131,6 +131,35 @@ class SyncCollectionsFromPulpServerTestCase(TestCaseUsingBindings, SyncHelpersMi
         messages = [r.message for r in task.progress_reports]
         self.assertIn(msg, str(messages))
 
+    def test_noop_resync_with_mirror_from_pulp(self):
+        """Test whether no-op sync with mirror=True doesn't remove repository content."""
+        second_body = gen_ansible_remote(
+            url=self.distribution.client_url,
+            requirements_file=self.requirements_file,
+            sync_dependencies=False,
+        )
+        second_remote = self.remote_collection_api.create(second_body)
+        self.addCleanup(self.remote_collection_api.delete, second_remote.pulp_href)
+
+        second_repo = self._create_repo_and_sync_with_remote(second_remote)
+
+        second_content = self.cv_api.list(repository_version=f"{second_repo.pulp_href}versions/1/")
+        self.assertGreaterEqual(len(second_content.results), 1)
+
+        # Resync
+        repository_sync_data = AnsibleRepositorySyncURL(
+            remote=second_remote.pulp_href, optimize=True, mirror=True
+        )
+        sync_response = self.repo_api.sync(second_repo.pulp_href, repository_sync_data)
+        monitor_task(sync_response.task)
+        second_repo = self.repo_api.read(second_repo.pulp_href)
+        self.assertEqual(int(second_repo.latest_version_href[-2]), 1)
+        task = tasks.read(sync_response.task)
+
+        msg = "no-op: {url} did not change since last sync".format(url=second_remote.url)
+        messages = [r.message for r in task.progress_reports]
+        self.assertIn(msg, str(messages))
+
     def test_update_requirements_file(self):
         """Test requirements_file update."""
         body = gen_ansible_remote(
@@ -168,14 +197,17 @@ class AutomationHubV3SyncCase(unittest.TestCase, SyncHelpersMixin):
         cls.distributions_api = DistributionsAnsibleApi(cls.client)
         cls.collections_api = PulpAnsibleGalaxyApiCollectionsApi(cls.client)
         cls.cv_api = ContentCollectionVersionsApi(cls.client)
+        cls.url = "https://cloud.redhat.com/api/automation-hub/"
+        cls.aurl = (
+            "https://sso.redhat.com/auth/realms/redhat-external/protocol/openid-connect/token"
+        )
 
     def test_sync_with_token_from_automation_hub(self):
         """Test whether we can sync with an auth token from Automation Hub."""
-        aurl = "https://sso.redhat.com/auth/realms/redhat-external/protocol/openid-connect/token"
         body = gen_ansible_remote(
-            url="https://cloud.redhat.com/api/automation-hub/",
+            url=self.url,
             requirements_file="collections:\n  - ansible.posix",
-            auth_url=aurl,
+            auth_url=self.aurl,
             token=os.environ["AUTOMATION_HUB_TOKEN_AUTH"],
             rate_limit=10,
             tls_validation=False,
@@ -189,7 +221,45 @@ class AutomationHubV3SyncCase(unittest.TestCase, SyncHelpersMixin):
         original_content = self.cv_api.list(repository_version=f"{repo.pulp_href}versions/1/")
         self.assertTrue(len(original_content.results) >= 3)  # check that we have at least 3 results
 
+    @unittest.skip("Skipping until synclist no longer creates new repository")
+    def test_syncing_with_excludes_list_from_automation_hub(self):
+        """Test if syncing collections know to be on the synclist will be mirrored."""
+        namespace = "autohubtest2"
+        # Collections are randomly generated, in case of failure, please change the names below:
+        name = "collection_dep_a_zzduuntr"
+        excluded = "collection_dep_a_tworzgsx"
+        excluded_version = "awcrosby.collection_test==2.1.0"
+        requirements = f"""
+        collections:
+          - {namespace}.{name}
+          - {namespace}.{excluded}
+          - {excluded_version}
+        """
+        body = gen_ansible_remote(
+            url=self.url,
+            requirements_file=requirements,
+            auth_url=self.aurl,
+            token=os.environ["AUTOMATION_HUB_TOKEN_AUTH"],
+            rate_limit=10,
+            tls_validation=False,
+            sync_dependencies=False,
+        )
+        remote = self.remote_collection_api.create(body)
+        self.addCleanup(self.remote_collection_api.delete, remote.pulp_href)
 
+        repo = self._create_repo_and_sync_with_remote(remote)
+
+        # Assert that at least one CollectionVersion was downloaded
+        repo_ver = f"{repo.pulp_href}versions/1/"
+        content = self.cv_api.list(repository_version=repo_ver)
+        self.assertTrue(content.count >= 1)
+
+        # Assert that excluded collection was not synced
+        exclude_content = self.cv_api.list(repository_version=repo_ver, name=excluded)
+        self.assertTrue(exclude_content.count == 0)
+
+
+# TODO QA-AH has been deprecated, remove/replace tests
 @unittest.skipUnless(
     "CI_AUTOMATION_HUB_TOKEN_AUTH" in os.environ,
     "'CI_AUTOMATION_HUB_TOKEN_AUTH' env var is not defined",
